/**
 * Created by andre on 31.08.18.
 */
Ext.define("demo.view.OldMainController", {
    extend: "Ext.app.ViewController",
    alias : "controller.demoMainController",

    listen: {
        global: {
            coreDataUnlocked  : "checkLock",
            coreDataLocked    : "checkLock",
            coreDataLockUpdate: "checkLock"
        }
    },

    control: {
        "#": {
            afterrender: "checkLock"
        },
        "colorselector": {
            change: "pickAColor"
        }
    },

    init: function () {
        this.getViewModel().bind("{record}", this.setMonitorData.bind(this));
        this.getViewModel().bind("{transparence}", this.pickAColor.bind(this,undefined,undefined));

    },

    setMonitorData: function (record) {
        try {
            if (record) {
                var target = this.getView().down("#monitorData");
                target.removeAll();
                Ext.Object.each(record.getData(), function (key, value) {
                    target.add({
                        xtype     : "textfield",
                        fieldLabel: key,
                        value     : value
                    });
                });
            }
        }
        catch (e) {
            Ext.log({msg: this.self.getName() + ": ERROR setMonitorData", dump: e, stack: true, level: "error"});
        }
    },

    eineFunktion: function () {
        //setting holen

        var connectionId  = BpcCommon.Api.getSetting("demo", "backendConnectionId");
        var endpoint      = BpcCommon.Api.getSetting("demo", "httpEndpoint");
        var connectionUrl = BpcCommon.Api.getBackendUrl(connectionId);
        var vm            = this.getViewModel();

        Ext.Ajax.request({
            url    : connectionUrl + "/ibis/servlet/IBISHTTPUploadServlet/" + endpoint,
            method : "POST",
            params : {
                hallo    : "welt",
                status   : vm.get("record.STATUS"),
                text     : vm.get("record.TEXT"),
                processid: vm.get("record.PROCESSID"),
                user     : BpcCommon.Api.getUserName()
            },
            success: this.onSuccess.bind(this),
            failure: this.onFailure.bind(this)
        });


        BpcCommon.Api.showNotification("Ist raus");
    },

    onSuccess: function () {
        Ext.log({
            msg  : this.self.getName() + ": onSuccess",
            level: "info"
        });

        BpcCommon.Api.showNotification("OK");
    },

    onFailure: function () {
        Ext.log({
            msg  : this.self.getName() + ": onFailure",
            level: "info"
        });

        BpcCommon.Api.showNotification("Fehler");

    },

    letsChat: function () {
        Ext.log({
            msg  : this.self.getName() + ": letsChat",
            level: "info"
        });
        Ext.create({
            xtype  : "bpcWindow",
            items  : [{xtype: "demoChat"}],
            title  : "demo Demo - Chat",
            iconCls: "x-fal fa-comments"
        });
    },

    applyLock: function () {

        Ext.fireEvent("chat", {
            text: BpcCommon.Api.getUserName() + " locked the demo module 🔒",
            user: "✌️Virtimo",
            date: new Date()
        });
        BpcCommon.Api.lockData("demo", "lockdemo");
        this.unlockBtnFn = BpcCommon.Util.blockComponentForAsyncAction("applyLock", "buttonType");
    },

    releaseLock: function () {

        Ext.fireEvent("chat", {
            text: BpcCommon.Api.getUserName() + " UNlocked the demo module 🔓",
            user: "✌️Virtimo",
            date: new Date()
        });
        BpcCommon.Api.unlockData("demo", "lockdemo");
        if (Ext.isFunction(this.unlockBtnFn)) {
            this.unlockBtnFn();
            delete this.unlockBtnFn;
        }
    },

    checkLock: function () {
        var lock = BpcCommon.Api.getLockInformation("demo", "lockdemo");
        if (lock && lock.get("user")) {
            if (BpcCommon.Api.getUserName() === lock.get("user")) {
                //my lock
                if (!this.unlockBtnFn) {
                    this.unlockBtnFn = BpcCommon.Util.blockComponentForAsyncAction("applyLock", "buttonType");
                }
            } else {
                //other user
                this.getView().mask("Gesperrt durch " + lock.get("user"));
            }
        } else {
            this.getView().unmask();
            if (Ext.isFunction(this.unlockBtnFn)) {
                this.unlockBtnFn();
                delete this.unlockBtnFn;
            }
        }
    },

    sendNotification: function () {
        var vm               = this.getViewModel();
        var notificationText = Ext.util.Format.date(new Date(), "H:i:s") + " " + vm.get("notificationText");
        var toastTarget      = undefined;
        if (vm.get("notificationToastTarget") && vm.get("notificationToastTarget").notificationToastTarget === "module") {
            toastTarget = this.getView();
        } else if (vm.get("notificationToastTarget") && vm.get("notificationToastTarget").notificationToastTarget === "fieldset") {
            toastTarget = this.getView().down("#notificationFieldSet");
        }

        BpcCommon.Api.showNotification({
            text       : notificationText,
            type       : vm.get("notificationType").notificationType,
            popUp      : vm.get("notificationPopUp"),
            toast      : vm.get("notificationToast"),
            toastTarget: toastTarget,
            silent     : vm.get("notificationSilent")
        });
    },

    pickAColor: function (colorSelector) {
        var setting = BpcCommon.Api.getSetting("_core","gui_stageColor", true);
        this.lastColor = colorSelector.getValue();
        var transparence = colorSelector.childViewModel.get("alpha");
        var translatedColor = "#" + this.lastColor + Math.ceil(transparence * 2.55).toString(16);
        setting.set("value",translatedColor);
    },
    injectButtons: function(){
        BpcCommon.Api.addItemToAppToolbar([
            {
                xtype  : "button",
                iconCls: "x-fal fa-lock",
                buttonType: "applyLock",
                handler: this.applyLock.bind(this)
            },
            {
                xtype  : "button",
                iconCls: "x-fal fa-lock-open",
                handler: this.releaseLock.bind(this)
            }
        ]);
    },

    startMeasure: function(){
        Ext.log({msg: this.self.getName() + ": startMeasure", level: "info"});
        this.unlockMeasureBtn = BpcCommon.Util.blockComponentForAsyncAction("startMeasure","handler");
        BpcCommon.Performance.mark("demo_demo_start");
    },

    stopMeasure: function () {
        Ext.log({msg: this.self.getName() + ": stopMeasure", level: "info"});
        if (this.unlockMeasureBtn){
            this.unlockMeasureBtn();
            delete this.unlockMeasureBtn;
            BpcCommon.Performance.mark("demo_demo_end");
            BpcCommon.Performance.measure("demo_demo","demo_demo_start","demo_demo_end");
            var mArray = performance.getEntriesByType("measure");
            var  measurement = mArray[mArray.length - 1];
            var vm               = this.getViewModel();
            vm.set("measurement",measurement);
        }
    }
});